<?php
/**
 * @link              https://www.matrixwebdesigners.com/
 * @since             1.0.0
 * @package           wc_hide_categories
 *
 * @wordpress-plugin
 * Plugin Name:       Hide WooCommerce Categories On Shop Page
 * Plugin URI:        https://www.matrixwebdesigners.com/plugins/woocommerce-hide-categories-shop-page/
 * Description:       Simple solution to hide specific categories in you woocommerce shop main page i.e. domain.com/shop This plugin was based on WC Hide Categories On Shop Page located at https://wordpress.org/plugins/wc-hide-categories-on-shop-page/ However it did not work and wasn't maintained.
 * Version:           1.0.1
 * Author:            Matix Web Designers
 * Author URI:        https://www.matrixwebdesigners.com/
 * License:           GPL-3.0+
 * License URI:       http://www.gnu.org/licenses/gpl-3.0.txt
 * Text Domain:       hwcosp
 * Domain Path:       /languages
 */

// If this file is called directly, abort.

// Exit if accessed directly.
defined( 'ABSPATH' ) || exit; 

/**
 * Check if WooCommerce is active, if its not then we dont need this plugin
 **/
if ( !in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {
    
    add_action( 'admin_notices', 'mwd_hide_woocommerce_categories_admin_notice' );
    
}else{
    
	/**
	* Create the section beneath the products tab
	* Using WooCommerce Hooks and Filters
	**/
	
	//  Add Hide Categories On Shop Page WooCommerce Setting Section
	
	add_filter( 'woocommerce_get_sections_products', 'mwd_hide_woocommerce_categories_hide_category_setting_section' );
	
	function mwd_hide_woocommerce_categories_hide_category_setting_section( $sections ) {
	
		$sections['mwd_hide_woocommerce_categories_product_settings_section'] = __( 'Hide Categories On Shop Page', 'hwcosp' );
		return $sections;
	
	}
	
	// Add WooCommerce  Setting For excluding Category From Shop Page
	add_filter( 'woocommerce_get_settings_products', 'mwd_hwcosp_add_wc_exclude_setting', 10, 2 );
	 
	function mwd_hwcosp_add_wc_exclude_setting( $settings ,  $current_section) {
	
		$settings_url = array();
	       
		// Add Title to the Settings
		if( $current_section == 'mwd_hide_woocommerce_categories_product_settings_section'){
		
			$settings_url[] = array( 'name' => __( 'Hide categories on shop page', 'hwcosp' ), 'type' => 'title', 'desc' => __( 'The following options are used to configure Hide categories on shop page', 'hwcosp' ), 'id' => 'hwcosp' );
		
			// Add  text option
		
			$settings_url[] = array(
				'name'     => __( 'Hide Categories', 'hwcosp' ),
				'desc_tip' => __( 'This will Hide Categories From Shop Page', 'hwcosp' ),
				'id'       => 'hwcosp_global',
				'type'     => 'text',
				'css'      => 'min-width:300px;',
				'desc'     => __( 'Put the categories which are to be excluded <b>eg : abc,xyz</b>', 'hwcosp' ),
			);
			
			return $settings_url;
		
		}else{
			return $settings;
		}
	}
	
	/* hide category */
	
	/**
	 * @param $string - Input string to convert to array
	 * @param string $separator - Separator to separate by (default: ,)
	 *
	 * @return array
	 */
	
	function mwd_hwcosp_comma_separated_to_array($string, $separator = ',')
	{
	  //Explode on comma
	  $vals = explode($separator, $string);
	 
	  //Trim whitespace
	  foreach($vals as $key => $val) {
	    $vals[$key] = trim($val);
	  }
	  //Return empty array if no items found
	  //http://php.net/manual/en/function.explode.php#114273
	  return array_diff($vals, array(""));
	}
	
	add_filter( 'get_terms', 'mwd_hwcosp_get_subcategory_terms', 10, 3 );

	function mwd_hwcosp_get_subcategory_terms( $terms, $taxonomies, $args ) {
		
		//$data = array();
		$opt_terms = get_option('hwcosp_global');
		
		$data = mwd_hwcosp_comma_separated_to_array($opt_terms);
		
		$new_terms = array();
	
		// if a product category and on the shop page
		// to hide from shop page, replace is_page('YOUR_PAGE_SLUG') with is_shop()
		//if ( in_array( 'product_cat', $taxonomies ) && ! is_admin() && is_page('YOUR_PAGE_SLUG') ) {
		
		// Test some variations user may have for their shop
		// ToDo make a dropdown select of current pages
		
		// If you need a different page just uncomment out remove // in front of $mwd_opt4 and /* */
		// Then insert your page slug
		
		$mwd_opt1 = in_array( 'product_cat', $taxonomies ) && ! is_admin() && is_shop();
		$mwd_opt2 = in_array( 'product_cat', $taxonomies ) && ! is_admin() && is_front_page();
		$mwd_opt3 = in_array( 'product_cat', $taxonomies ) && ! is_admin() && is_home();
		//$mwd_opt4 = in_array( 'product_cat', $taxonomies ) && ! is_admin() && is_page('YOUR_PAGE_SLUG'),
		
			if ( $mwd_opt1 || $mwd_opt2 || $mwd_opt3 /*|| $mwd_opt4*/ ) {
			
				foreach ( $terms as $key => $term ) {
					
					if ( ! in_array( $term->slug, $data ) ) {
						
						$new_terms[] = $term;
					}
				}
				
				$terms = $new_terms;
			}
		
		return $terms;
		
	}
}

/* Admin notice if WooCommerce is not installed or active */
function mwd_hide_woocommerce_categories_admin_notice(){
    echo '<div class="notice notice-error">';
    echo     '<p>'. _e( 'WC Hide Categories On Shop Page requires an active WooCommerce Installation!', 'hwcosp' ).'</p>';
    echo '</div>';
}